@@ -20,7 +20,7 @@ _LOGGER = logging.getLogger(__name__)
 
 
 class Tibber:
-    """Class to comunicate with the Tibber api."""
+    """Class to communicate with the Tibber api."""
 
     # pylint: disable=too-many-instance-attributes
 
@@ -45,6 +45,7 @@ class Tibber:
         self._access_token = access_token
         self.time_zone = time_zone or pytz.utc
         self._name = None
+        self._user_id = None
         self._home_ids = []
         self._all_home_ids = []
         self._homes = {}
@@ -125,11 +126,12 @@ class Tibber:
         {
           viewer {
             name
+            userId
             homes {
+              id
               subscriptions {
                 status
               }
-              id
             }
           }
         }
@@ -151,6 +153,8 @@ class Tibber:
         if not viewer:
             return
         self._name = viewer.get("name")
+        self._user_id = viewer.get("userId")
+
         homes = viewer.get("homes", [])
         self._home_ids = []
         for _home in homes:
@@ -163,6 +167,11 @@ class Tibber:
                     continue
             self._home_ids += [home_id]
 
+    @property
+    def user_id(self):
+        """Return user id of user."""
+        return self._user_id
+
     @property
     def name(self):
         """Return name of user."""
@@ -451,7 +460,7 @@ class TibberHome:
             sub = self.info["viewer"]["home"]["currentSubscription"]["status"]
         except (KeyError, TypeError):
             return False
-        return sub in ["running", "awaiting market"]
+        return sub in ["running", "awaiting market", "awaiting time restriction"]
 
     @property
     def has_real_time_consumption(self):
@@ -556,7 +565,6 @@ class TibberHome:
         return (
             self._tibber_control.sub_manager is not None
             and self._tibber_control.sub_manager.is_running
-            and self._subscription_id is not None
         )
 
     async def get_historic_data(self, n_data, resolution=RESOLUTION_HOURLY):
